/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.syn.controllers.obj

import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.datacenter.models.entities.dictnew.DictProject
import com.persagy.server.datacenter.models.entities.objects.Equipment
import com.persagy.server.datacenter.models.entities.rel.REqForBd
import com.persagy.server.datacenter.models.entities.rel.REqForFl
import com.persagy.server.syn.Configure
import com.persagy.server.syn.models.api.obj.EquipApi
import com.persagy.service.SBaseService
import com.persagy.service.SObjectService
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.responses.SBaseResponse
import io.swagger.v3.oas.annotations.Operation
import io.swagger.v3.oas.annotations.tags.Tag
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 关系数据-数据中心同步到数据中台
 *
 * @author wx  <zhangweixin@sagacloud.com>
 * @date  2020/11/26 14:52
 */
@Tag(name = "0004、关系-数据中心到中台")
@RestController
@RequestMapping("/datacenter/object/sync")
class RelToFromController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(ObjectToFromController::class.java)
    } // Companion object

    /** 设备服务楼层 */
    private val rEqForFlService = SBaseService(SMybatisDao(REqForFl::class.java))
    /** 设备服务建筑 */
    private val rEqForBdService = SBaseService(SMybatisDao(REqForBd::class.java))
    /** 数据中心设备服务 */
    private val equipmentService = SObjectService(SMybatisDao(Equipment::class.java))
    /** 字典项目服务 */
    private val dictProjectService = SBaseService(SMybatisDao(DictProject::class.java))



    /**
     * 设备和楼层关系-同步到中台
     *
     * @param projectId     项目id
     * @param graphCode     图类型
     * @param type          边类型
     * @param isDel         是否删除以前的关系
     * @return 返回是否成功结果
     */
    @Operation(summary= "设备和楼层关系-同步到中台", description = "设备所在的楼层(图类型 MechInArch 边类型 Eq2Fl )，设备服务的楼层（图类型 MechForArch 边类型 Eq2Fl）, ")
    @PostMapping("/eq2fl")
    fun eq2Fl(projectId: String,graphCode: String,type: String,isDel: Boolean = false): SBaseResponse {
        try {
            val dictProject = dictProjectService.select(SFilter.eq("id", projectId)).entity()
            if (graphCode == "MechInArch") {
                val equipmentList = equipmentService.select(SFilter.eq("projectId", projectId)).exec()
                if (equipmentList.size>0) {
                    for (equipment in equipmentList) {
                        val toJsonObjArray =
                            Configure.toJsonObjArray(graphCode, type, equipment.id!!, equipment.floorId!!)
                        if (isDel) {
                            val toJsonObj = Configure.toJsonObj(graphCode, type, equipment.id!!, null)
                            EquipApi.delRel(dictProject!!.groupCode!!, projectId,toJsonObj)
                        }
                        val createRel = EquipApi.createRel(dictProject!!.groupCode!!, projectId, toJsonObjArray)
                        if (!createRel){
                            logger.debug("设备所在楼层的关系失败：${toJsonObjArray.toJson()}")
                        }
                    }
                }
            } else if (graphCode == "MechForArch") {
                val rEqForFlList = rEqForFlService.select(SFilter.eq("projectId", projectId)).exec()
                if (rEqForFlList.size>0) {
                    for (rEqForFl in rEqForFlList) {
                        if (isDel) {
                            val toJsonObj = Configure.toJsonObj(graphCode, type, rEqForFl.equipId!!, null)
                            EquipApi.delRel(dictProject!!.groupCode!!, projectId,toJsonObj)
                        }
                        val toJsonObjArray =
                            Configure.toJsonObjArray(graphCode, type, rEqForFl.equipId!!, rEqForFl.floorId!!)
                        val createRel = EquipApi.createRel(dictProject!!.groupCode!!, projectId, toJsonObjArray)
                        if (!createRel){
                            logger.debug("设备服务楼层的关系失败：${toJsonObjArray.toJson()}")
                        }
                    }
                }
            }
            return SBaseResponse(SResponseType.success)
        } catch (e: Exception) {
            e.printStackTrace()
            return SBaseResponse(SResponseType.failure,e.message!!)
        }
    }

    /**
     * 设备和建筑关系-同步到中台
     *
     * @param projectId     项目id
     * @param graphCode     图类型
     * @param type          边类型
     * @param isDel         是否删除以前的关系
     * @return 返回是否成功结果
     */
    @Operation(summary= "设备和楼层关系-同步到中台", description = "设备所在的建筑(图类型 MechInArch 边类型 Eq2Bd )，设备服务的建筑（图类型 MechForArch 边类型 Eq2Bd）, ")
    @PostMapping("/eq2bd")
    fun eq2Bd(projectId: String,graphCode: String,type: String,isDel: Boolean = false): SBaseResponse {
        try {
            val dictProject = dictProjectService.select(SFilter.eq("id", projectId)).entity()
            if (graphCode == "MechInArch") {
                val equipmentList = equipmentService.select(SFilter.eq("projectId", projectId)).exec()
                if (equipmentList.size>0) {
                    for (equipment in equipmentList) {
                        val toJsonObjArray =
                            Configure.toJsonObjArray(graphCode, type, equipment.id!!, equipment.buildingId!!)
                        if (isDel) {
                            val toJsonObj = Configure.toJsonObj(graphCode, type, equipment.id!!, null)
                            EquipApi.delRel(dictProject!!.groupCode!!, projectId,toJsonObj)
                        }
                        val createRel = EquipApi.createRel(dictProject!!.groupCode!!, projectId, toJsonObjArray)
                        if (!createRel){
                            logger.debug("设备所在建筑的关系失败：${toJsonObjArray.toJson()}")
                        }
                    }
                }
            } else if (graphCode == "MechForArch") {
                val rEqForFlList = rEqForBdService.select(SFilter.eq("projectId", projectId)).exec()
                if (rEqForFlList.size>0) {
                    for (rEqForFl in rEqForFlList) {
                        if (isDel) {
                            val toJsonObj = Configure.toJsonObj(graphCode, type, rEqForFl.equipId!!, null)
                            EquipApi.delRel(dictProject!!.groupCode!!, projectId,toJsonObj)
                        }
                        val toJsonObjArray =
                            Configure.toJsonObjArray(graphCode, type, rEqForFl.equipId!!, rEqForFl.buildingId!!)
                        val createRel = EquipApi.createRel(dictProject!!.groupCode!!, projectId, toJsonObjArray)
                        if (!createRel){
                            logger.debug("设备服务建筑的关系失败：${toJsonObjArray.toJson()}")
                        }
                    }
                }
            }
            return SBaseResponse(SResponseType.success)
        } catch (e: Exception) {
            e.printStackTrace()
            return SBaseResponse(SResponseType.failure,e.message!!)
        }
    }


    /**
     * 设备和系统关系
     */
    @Operation(summary= "设备和系统关系-同步到中台", description = "系统下设备(图类型 MechSubset 边类型 Sy2Eq )")
    @PostMapping("/sy2eq")
    fun sy2Eq(projectId: String,graphCode: String,type: String,isDel: Boolean = false){
        val dictProject = dictProjectService.select(SFilter.eq("id", projectId)).entity()
    }

    /**
     * 设备和竖井关系
     */
    @Operation(summary= "设备和竖井关系-同步到中台", description = "设备所在的竖井(图类型 MechInArch 边类型 Eq2Bd )，设备服务的竖井（图类型 MechForArch 边类型 Eq2Sh）, ")
    @PostMapping("/eq2sh")
    fun eq2Sh(projectId: String,graphCode: String,type: String,isDel: Boolean = false){
        val dictProject = dictProjectService.select(SFilter.eq("id", projectId)).entity()
    }

    /**
     * 设备和空间关系
     */
    @Operation(summary= "设备和空间关系-同步到中台", description = "设备所在的空间(图类型 MechInArch 边类型 Eq2Sp )，设备服务的空间（图类型 MechForArch 边类型 Eq2Sp）, ")
    @PostMapping("/eq2sp")
    fun eq2Sp(projectId: String,graphCode: String,type: String,isDel: Boolean = false){
        val dictProject = dictProjectService.select(SFilter.eq("id", projectId)).entity()
    }

    /**
     * 设备和部件关系
     */
    fun eq2Ec(projectId: String,graphCode: String,type: String,isDel: Boolean = false){
        val dictProject = dictProjectService.select(SFilter.eq("id", projectId)).entity()
    }


}