/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.syn.jms

import com.persagy.server.datacenter.models.jms.SynchronousMessage
import com.persagy.server.syn.Configure
import com.persagy.server.syn.services.jms.*
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.stereotype.Service

/**
 * 数据中心 - 数据处理
 *
 * @author wx  <zhangweixin@sagacloud.com>
 * @date  2020/11/1 22:22
 */
@Service
class DataCenterSync {
    /** 建筑 */
    @Autowired
    lateinit var dataCenterBuilding: DataCenterBuilding
    /** 楼层 */
    @Autowired
    lateinit var dataCenterFloor: DataCenterFloor
    /** 设备 */
    @Autowired
    lateinit var dataCenterEquip: DataCenterEquipment
    /** 部件 */
    @Autowired
    lateinit var dataCenterComponent: DataCenterComponent
    /** 竖井 */
    @Autowired
    lateinit var dataCenterShaft: DataCenterShaft
    /** 系统 */
    @Autowired
    lateinit var dataCenterSystem: DataCenterSystem
    /** 空间 */
    @Autowired
    lateinit var dataCenterSpace: DataCenterSpace


    /**
     * 数据中心到 - 中台数据
     *
     * @param messageList   消息列表
     */
    fun dataSync(messageList:ArrayList<SynchronousMessage>): Boolean {
        for (message in messageList){
            when(message.objectType){
                Configure.PROJECT -> { /** 项目信息 */}
                Configure.BUILDING -> {
                    /** 建筑 */
                    dataCenterBuilding.buildingType(message)
                }
                Configure.FLOOR -> {
                    /** 楼层 */
                    dataCenterFloor.floorType(message)
                }
                Configure.EQUIPMENT -> {
                    /** 设备 */
                    dataCenterEquip.equipType(message)
                }
                Configure.COMPONENT -> {
                    /** 部件 */
                    dataCenterComponent.equipType(message)
                }
                Configure.SHAFT -> {
                    /** 竖井 */
                    dataCenterShaft.shaftType(message)
                }
                Configure.SYSTEM -> {
                    /** 系统 */
                    dataCenterSystem.systemType(message)
                }
                Configure.SPACE -> {
                    /** 空间 */
                    dataCenterSpace.spaceType(message)
                }
            }
        }
        return true
    }


}