/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.controllers

import com.persagy.database.SFilter
import com.persagy.server.models.PropertyEquip
import com.persagy.server.models.PropertyFamily
import com.persagy.server.models.requests.EquipUpDateEnclosure
import com.persagy.server.models.requests.EquipUpDateEnclosureRequest
import com.persagy.server.service.PropertyEquipService
import com.persagy.server.service.PropertyFamilyService
import com.persagy.service.SPageContext
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.v3.oas.annotations.Operation
import io.swagger.v3.oas.annotations.tags.Tag
import org.springframework.web.bind.annotation.*

/**
 * 资产接口
 *
 * @author 张维新
 */
@Tag(name = "资产相关接口")
@RestController
@RequestMapping("/property")
class PropertyController {

    /**
     * 查询资产关联设备
     */
   @Operation(summary = "查询资产 同时关联设备信息", description = " 设备相关字段：LinkeEquipName、LinkeEquipId、LinkeEquipLocalName")
    @PostMapping(value = ["/property-query"])
    fun pageQueryProperty(@RequestBody request: SQueryRequest): SQueryResponse<PropertyEquip> {
        val withFilterList = ArrayList<SFilter>()
        withFilterList.add(SFilter.eq("projectId", SPageContext.getHeader("projectId").toString()))
        return PropertyEquipService.pageQuery(request, withFilterList)
    } // Function pageQueryProperty()

    /**
     * 查询项目下的设备族分类 以及数量
     */
   @Operation(summary = "查询项目下的设备族分类 以及相同设备族资产的数量数量", description = " ")
    @GetMapping(value = ["/property-family"])
    fun pageQueryPropertyFamily(buildingId: String?, floorId: String?,startTime: String?, endingTime: String?,pointId: String?, checked: String?): SQueryResponse<PropertyFamily> {
        return PropertyFamilyService.queryFamily(buildingId,floorId,startTime,endingTime,pointId,checked)
    } // Function pageQueryProperty()

    /**
     * 修改资产的附件功能
     */
   @Operation(summary = " 修改资产的附件功能", description = "")
    @PostMapping(value = ["/update"])
    fun equipUpDateEnclosure(@RequestBody equipUpDateEnclosureRequest: EquipUpDateEnclosureRequest<EquipUpDateEnclosure>) : SBaseResponse {
        return PropertyEquipService.equipUpDateEnclosurs(equipUpDateEnclosureRequest)
    } // Function equipUpDateEnclosure()

} // Class PropertyContrpller