/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.labsl.controller

import com.persagy.database.SFilter
import com.persagy.server.labsl.models.entities.Graph
import com.persagy.server.labsl.models.entities.pub.GraphPub
import com.persagy.server.labsl.models.response.SCommonResponse
import com.persagy.server.labsl.services.GraphService
import com.persagy.server.labsl.services.pub.GraphPubService
import com.persagy.service.SPageContext
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 图形
 *
 * @author wx  <zhangweixin@sagacloud.com>
 */
@Tag(name = ["001、系统图"])
@RestController
@RequestMapping("/graph")
class GraphController {

    /**
     * 创建图
     *
     * @param request     待图对象列表
     * @return 创建完成图对象列表
     */
   @Operation(summary="草稿箱-创建图", description ="id和graphId为必填，图中会包含多个节点，详细节点结构见示例")
    @PostMapping("/drafts/create")
    fun create(@RequestBody request: SCreateRequest<Graph>): SCreateResponse<Graph> {
        return GraphService.createList(request)
    } // Function create()

    /**
     * 提交图形
     *
     * @param  graph   待图对象
     * @return  图对象列表
     */
   @Operation(summary="草稿箱-保存图形", description ="")
    @PostMapping("/drafts/save")
    fun save(@RequestBody graph: Graph): SCreateResponse<Graph> {
        return GraphService.save(graph)
    } // Function save()

    /**
     * 发布图形
     *
     * @param graph     待发布的图对象
     * @return 发布结果
     */
   @Operation(summary="草稿箱-发布图形", description =" Id 和 GraphId 必须填写")
    @PostMapping("/drafts/publish")
    fun pubDrawings(@RequestBody graph: GraphPub): SCreateResponse<GraphPub>{
        return GraphService.pubDrawings(graph)
    } // Function pubDrawings()


    /**
     * 图、移至或移出回收站
     *
     * @param idList    图例列表
     * @return 移出结果
     */
   @Operation(summary = "草稿箱-移至回收站", description = " Id 和 GraphId 必填")
    @PostMapping(value = ["/drafts/recycle"])
    fun recycle(@RequestBody idList: ArrayList<Graph>): SBaseResponse {
        return GraphService.recycle(idList)
    } // Function recycle()

    /**
     * 已发布图形移至回收站
     *
     * @param idList    图列表
     * @return 移出结果
     */
   @Operation(summary = "已发布-图形移至回收站", description = "Id 和 GraphId 必填")
    @PostMapping(value = ["/pub/recycle"])
    fun recyclePub(@RequestBody idList: ArrayList<Graph>): SBaseResponse{
        return GraphService.recyclePub(idList)
    } // Function recyclePub()

    /**
     * 更新图形信息
     *
     * @param request   更新的内容对象
     * @return 更新的结果
     */
   @Operation(summary = "草稿箱-更新图形信息", description = "Id 和 GraphId 必填")
    @PostMapping(value = ["/drafts/update"])
    fun update(@RequestBody request: SUpdateRequest<Graph>): SBaseResponse {
        return GraphService.updateList(request)
    } // Function update()

    /**
     * 查询图形信息
     *
     * @param  request  查询条件
     * @return 查询结果
     */
   @Operation(summary = "草稿箱-查询图形信息", description = "state 1(草稿箱)，state 4(回收站) ，Id 和 GraphId 必填")
    @PostMapping(value = ["/drafts/query"])
    fun query(@RequestBody request: SQueryRequest): SQueryResponse<Graph> {
        val projectId = SPageContext.getHeader("projectId")
        return GraphService.pageQuery(request, arrayListOf(SFilter.eq("projectId",projectId!!)))
    } // Function query()

    /**
     * 草稿箱 - 读取图形所有节点
     *
     * @param graph  图例对象
     * @return 查询结果
     */
   @Operation(summary = "草稿箱-查询图形以及所有节点信息", description = "Id 和 GraphId 必填")
    @PostMapping(value = ["/drafts/read"])
    fun readDrafts(@RequestBody graph: Graph): SCommonResponse<Graph> {
        return GraphService.readDrafts(graph)
    } // Fun readDrafts()

    /**
     * 已发布 - 读取图形所有节点
     *
     * @param graph  图例对象】
     * @return 查询结果
     */
   @Operation(summary = "已发布-查询图形以及所有节点信息", description = "Id 和 GraphId 必填")
    @PostMapping(value = ["/pub/read"])
    fun readPub(@RequestBody graph: GraphPub): SCommonResponse<GraphPub>{
        return GraphService.readPub(graph)
    } // Fun readPub()

    /**
     * 已发布图形查询
     *
     * @param request  查询条件
     * @return 查询结果
     */
   @Operation(summary = "已发布-查询图形信息", description = "Id 和 GraphId 必填")
    @PostMapping(value = ["/pub/query"])
    fun querPub(@RequestBody request: SQueryRequest): SQueryResponse<GraphPub> {
        val projectId = SPageContext.getHeader("projectId")
        return GraphPubService.pageQuery(request, arrayListOf(SFilter.eq("projectId",projectId!!)))
    } // Function querPub()

    /**
     * 更新图形信息
     *
     * @param request  更新的内容对象
     * @return 更新的结果
     */
   @Operation(summary = "已发布-更新图形信息", description = "")
    @PostMapping(value = ["/pub/update"])
    fun updatePub(@RequestBody request: SUpdateRequest<GraphPub>): SBaseResponse {
        return GraphPubService.updateList(request)
    } // Function update()

    /**
     * 回收站- 恢复图形
     *
     * @param graph  图对象
     * @return 恢复结果
     */
   @Operation(summary = "回收站- 恢复图形", description = "Id 和 GraphId 必填 ")
    @PostMapping(value = ["recycle/recovery"])
    fun recovery(@RequestBody graph: Graph): SBaseResponse{
    return GraphService.recovery(graph)
    } // Fun recovery()

    /**
     * 根据id删除图形
     *
     * @param idList      图对象数组
     * @return 删除的结果信息
     */
   @Operation(summary = "回收站-根据id删除图形信息，删除草稿箱图形", description = "Id 和 GraphId 必填 ")
    @PostMapping(value = ["recycle/delete"])
    fun delete(@RequestBody idList: ArrayList<Graph>): SBaseResponse {
        return GraphService.deleteByKeysList(idList)
    } // Function delete()

} // Class GraphController