/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.labsl.controller

import com.persagy.server.labsl.models.entities.Markers
import com.persagy.server.labsl.services.MarkersService
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 文本注释，图上的图片说明
 *
 * @author wx  <zhangweixin@sagacloud.com>
 */
@Tag(name = ["003、系统图内标识信息，文本注释，图上的图片说明- 系统图下子对象"])
@RestController
@RequestMapping("/marker")
class MarkersController {

    /**
     * 注释说明
     *
     * @param request   待创建注释说明对象列表
     * @return  创建完成注释说明对象列表
     */
   @Operation(summary="注释说明创建", description ="id 为系统图的图对象id，graphId 为系统图的图 id ,markerId 为当前标识的id，id 和 graphId 必须填为某一个系统图中的 id，markerId 是当前要创建的对象id不传会自动生成（32位uuid）")
    @PostMapping("/create")
    fun create(@RequestBody request: SCreateRequest<Markers>): SCreateResponse<Markers> {
        return MarkersService.creates(request)
    } // Function create()

    /**
     * 根据id删除图注释说明
     *
     * @param idList    id数组
     * @return  删除的结果信息
     */
   @Operation(summary = "根据批量删除标识信息对象", description = "创建中有介绍id的说明请查看，删除时必须传入 id、graphId、markerId 才能确认删除的是当前的标识对象")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<Markers>): SBaseResponse {
        return MarkersService.deletes(idList)
    } // Function delete()

    /**
     * 更新注释说明信息
     *
     * @param request   更新的内容对象
     * @return 更新的结果
     */
   @Operation(summary = "批量更新标识信息", description = "创建中有介绍id的说明请查看，id、graphId、markerId 为必填信息点，参考创建后的对象信息点,修改哪个信息点直接写在对象里面即可，详细的使用方式参考 web 端接口使用规范")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<Markers>): SBaseResponse {
        return MarkersService.updateList(request)
    } // Function update()

    /**
     * 查询注释说明信息
     *
     * @param request   查询条件
     * @return 查询结果
     */
   @Operation(summary = "查询标识信息", description = "创建中有介绍id的说明请查看,注意 id、graphId、markerId 的区别，示例 查询某一个标识信息：filters = id ='值';graphId='值';markerId='值'    （其他的组合方式详见后端开发文档 web 端接口使用规范）")
    @PostMapping(value = ["/query"])
    fun query(@RequestBody request: SQueryRequest): SQueryResponse<Markers> {
        return MarkersService.pageQuery(request)
    } // Function query()

} // Class NodeController