/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.labsl.controller

import com.persagy.server.labsl.models.entities.Node
import com.persagy.server.labsl.services.NodeService
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.requests.SQueryRequest
import com.persagy.service.models.requests.SUpdateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import com.persagy.service.models.responses.SQueryResponse
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.springframework.web.bind.annotation.PostMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

/**
 * 图例节点
 *
 * @author wx  <zhangweixin@sagacloud.com>
 */
@Api(tags = ["002、系统图设备节点，与数据中台设备实例对应关系（绑定信息点在该设备上进行）- 系统图下子对象"])
@RestController
@RequestMapping("/node")
class NodeController {

    /**
     * 图例节点
     *
     * @param request   待创建图对象列表
     * @return  创建完成图例节点对象列表
     */
   @Operation(summary="创建设备节点", notes="id 为系统图的图对象id，graphId 为系统图的图id ,nodeId 为当前节点的id，id 和 graphId 必须填为某一个系统图中的 id，nodeId 是当前要创建的对象id不传会自动生成（32位uuid）")
    @PostMapping("/create")
    fun create(@RequestBody request: SCreateRequest<Node>): SCreateResponse<Node> {
        return NodeService.creates(request)
    } // Function create()

    /**
     * 根据id删除图例节点
     *
     * @param idList  id数组
     * @return 删除的结果信息
     */
   @Operation(summary = "根据id删除图例节点信息", notes = "创建中有介绍id的说明请查看，删除时必须传入 id、graphId、nodeId 才能确认删除的是当前的设备节点")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<Node>): SBaseResponse {
        return NodeService.deletes(idList)
    } // Function delete()

    /**
     * 更新图例节点信息
     *
     * @param  request   更新的内容对象
     * @return 更新的结果
     */
   @Operation(summary = "更新图例节点信息", notes = "创建中有介绍 id 的说明请查看，id、graphId、nodeId 为必填信息点，参考创建后的对象信息点，然后修改了哪个信息点传哪个信息点，详细的使用方式参考 web 端接口使用规范")
    @PostMapping(value = ["/update"])
    fun update(@RequestBody request: SUpdateRequest<Node>): SBaseResponse {
        return NodeService.updateList(request)
    } // Function update()

    /**
     * 查询图例节点信息
     *
     * @param  request 查询条件
     * @return 查询结果
     */
   @Operation(summary = "查询图例节点信息", notes = "创建中有介绍 id 的说明请查看,注意 id、graphId、nodeId 的区别，示例 查询某一个对象：filters = id ='值';graphId='值';nodeId='值' （其他的组合方式详见后端开发文档 web 端接口使用规范）")
    @PostMapping(value = ["/query"])
    fun query(@RequestBody request: SQueryRequest): SQueryResponse<Node> {
        return NodeService.pageQuery(request)
    } // Function query()

} // Class NodeController