/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.labsl.services

import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.labsl.models.entities.GraphCategory
import com.persagy.server.labsl.models.request.GraphCategoryRequest
import com.persagy.service.SObjectService
import com.persagy.service.SPageContext
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.responses.SQueryResponse
import com.persagy.service.utils.SSpringContextUtil

/**
 * 分类服务
 *
 * @author wx  <zhangweixin@sagacloud.com>
 * @date  2020/9/15 11:38
 */
object GraphCategoryService : SObjectService<GraphCategory>(SMybatisDao(GraphCategory::class.java)) {

    /** 自定义sql */
    private val customMapper by lazy {
        SSpringContextUtil.getBean(CustomService::class.java) as CustomService
    } // customMapper

    /**
     * 系统图分类查询
     *
     * @param request   查询条件对象
     * @return 查询结果
     */
    fun graphCategoryQuery(request: GraphCategoryRequest): SQueryResponse<GraphCategory> {
        /** 项目id */
        val projectId = SPageContext.getHeader("projectId")
        val sQueryResponse = SQueryResponse<GraphCategory>()
        return try {
            if (request.switch) {
                val graphCategoryList = select(SFilter.isNull("parentId")).exec()
                for (graphCategory in graphCategoryList) {
                    val treeClimate = treeClimate(graphCategory.id!!, true)
                    if (treeClimate.size > 0) {
                        graphCategory.categoryList = treeClimate
                    }
                }
                sQueryResponse.content = graphCategoryList
                sQueryResponse.total = graphCategoryList.size.toLong()
                sQueryResponse.result = SResponseType.success
                sQueryResponse
            } else {
                val calcAffectedList = customMapper.draftsCategory(projectId!!)
                val pubCategoryList = customMapper.pubCategory(projectId)
                val set = HashSet<String>()
                if (!pubCategoryList.isNullOrEmpty() || !calcAffectedList.isNullOrEmpty()) {
                    if (!pubCategoryList.isNullOrEmpty()) {
                        for (pubCategory in pubCategoryList) {
                            set.add(pubCategory.categoryId!!)
                        }
                    }
                    if (!calcAffectedList.isNullOrEmpty()) {
                        for (calcAffected in calcAffectedList) {
                            set.add(calcAffected.categoryId!!)
                        }
                    }
                    val graphCategoryList = select(SFilter.isNull("parentId")).exec()
                    for (graphCategory in graphCategoryList) {
                        val treeClimate = treeClimate(graphCategory.id!!, true)
                        if (treeClimate.size > 0) {
                            graphCategory.categoryList = treeClimate
                        }
                    }
                    for (id in set) {
                        for (graphCategory in graphCategoryList) {
                            if (graphCategory.id == id) {
                                graphCategory.sign = true
                            }
                            if (!graphCategory.categoryList.isNullOrEmpty()) {
                                val categoryList = graphCategory.categoryList!!
                                for (category in categoryList) {
                                    if (category.id == id) {
                                        category.sign = true
                                        graphCategory.sign = true
                                    }
                                    if (!category.categoryList.isNullOrEmpty()) {
                                        val categoryList1 = category.categoryList!!
                                        for (category2 in categoryList1) {
                                            if (category2.id == id) {
                                                category2.sign = true
                                                category.sign = true
                                                graphCategory.sign = true
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                    val iterator = graphCategoryList.iterator()
                    while (iterator.hasNext()) {
                        val next = iterator.next()
                        if (next.sign) {
                            if (!next.categoryList.isNullOrEmpty()) {
                                val iterator1 = next.categoryList!!.iterator()
                                while (iterator1.hasNext()) {
                                    val next1 = iterator1.next()
                                    if (next1.sign) {
                                        if (!next1.categoryList.isNullOrEmpty()) {
                                            val iterator2 = next1.categoryList!!.iterator()
                                            while (iterator2.hasNext()) {
                                                val next2 = iterator2.next()
                                                if (!next2.sign) {
                                                    iterator2.remove()
                                                }
                                            }
                                        }
                                    } else {
                                        iterator1.remove()
                                    }
                                }
                            }
                        } else {
                            iterator.remove()
                        }
                    }
                    sQueryResponse.content = graphCategoryList
                    sQueryResponse.total = graphCategoryList.size.toLong()
                } else {
                    sQueryResponse.content = ArrayList()
                }
                sQueryResponse.result = SResponseType.success
                sQueryResponse
            }
        } catch (e: Exception) {
            e.printStackTrace()
            sQueryResponse.result = SResponseType.failure
            sQueryResponse
        }
    } // Fun graphCategoryQuery()

    /**
     * 气候区 递归查询
     *
     * @param  parent        外键关系值
     * @param  hasChildren  是否进行递归查询
     * @return 类型列表
     */
    private fun treeClimate(parent: String, hasChildren: Boolean = true): ArrayList<GraphCategory> {
        val content = select("parentId" to parent).exec()
        if (hasChildren) {
            for (item in content) {
                try {
                    val children = treeClimate(item.id!!)
                    if (children.size > 0) {
                        item.categoryList = children
                    }
                } catch (e: Exception) {
                    // DO NOTHING
                }
            }
        }
        return content
    } // Function treeClimate()

} // Object GraphCategoryService