/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.labsl.services

import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.labsl.models.entities.Relation
import com.persagy.service.SObjectService
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.requests.SCreateRequest
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import org.springframework.web.bind.annotation.RequestBody
import java.util.*

/**
 * 管线对象
 *
 * @author wx  <zhangweixin@sagacloud.com>
 */
object RelationService : SObjectService<Relation>(SMybatisDao(Relation::class.java)){
    /**
     * 创建之前的操作
     *
     * @param entity    管线对象
     * @return 是否处理
     */
    override fun onCreateBefore(entity: Relation): Boolean {
        entity.id = UUID.randomUUID().toString().replace("-", "")
        return super.onCreateBefore(entity)
    } //


    /**
     * 创建管线对象
     *
     * @param request   创建管线对象列表
     * @return 返回结果
     */
    fun creates(request: SCreateRequest<Relation>): SCreateResponse<Relation> {
        /** 返回结果对象 */
        val sCreateResponse = SCreateResponse<Relation>()
        /** 返回结果中的状态 */
        sCreateResponse.result = SResponseType.failure
        return try {
            /** 项目 id */
//            val projectId = SPageContext.getHeader("projectId")
            /** 列表不可以为空 */
            if (!request.content.isNullOrEmpty()) {
                /** 遍历管线列表 */
                for (relation in request.content) {
                    /** 判断必传字段不可以为空 */
                    if (relation.id.isNullOrEmpty() || relation.graphId.isNullOrEmpty() || relation.name.isNullOrEmpty()) {
                        sCreateResponse.message = "注意必填字段不可以为空如 id、graphId、name"
                        return sCreateResponse
                    }
                    /** 查询 id 和 graphId 是否存在，是否可以定位一个系统图 */
                    val graphList =
                        GraphService.select(SFilter.eq("id", relation.id!!), SFilter.eq("graphId", relation.graphId!!))
                            .exec()
                    /** 图 id 和 graphId 不存在*/
                    if (graphList.size == 0) {
                        sCreateResponse.message = "请检查 id 和 graphId 是否为已有系统图中的 id"
                        return sCreateResponse
                    }
                }

                /** 遍历管线列表 */
                for (relation in request.content) {
                    /** 判断标记id是否没有，为空赋值 */
                    if (relation.relationId.isNullOrEmpty()) {
                        relation.relationId = UUID.randomUUID().toString().replace("-", "")
                    }

                    /** 插入数据 */
                    insert(relation)
                }

                sCreateResponse.entityList = request.content
                sCreateResponse.result = SResponseType.success
                sCreateResponse
            } else {
                sCreateResponse.message = "不可以传空列表"
                return sCreateResponse
            }
        } catch (e: Exception) {
            e.printStackTrace()
            sCreateResponse.message = e.message!!
            sCreateResponse
        }
    } // Fun creates()

    /**
     * 批量删除管线信息
     *
     * @param idList    管线对象列表
     * @return 返回结果
     */
    fun deletes(@RequestBody idList: ArrayList<Relation>): SBaseResponse {
        /** 返回结果对象 */
        val sBaseResponse = SBaseResponse()
        /** 返回结果状态 */
        sBaseResponse.result = SResponseType.failure
        return try {
            /** 列表不可以为空 */
            if (!idList.isNullOrEmpty()) {
                /** 遍历管线信息列表 */
                for (relation in idList) {
                    /** 校验必填信息点 */
                    if (relation.id.isNullOrEmpty() || relation.relationId.isNullOrEmpty()) {
                        sBaseResponse.message = "注意接口说明必填字段"
                        return sBaseResponse
                    }
                }

                /** 遍历管线信息列表 */
                for (relation in idList) {
                    /** 删除对象 */
                    delete(SFilter.eq("id", relation.id!!), SFilter.eq("relationId", relation.relationId!!))
                }

                /** 返回结果状态 */
                sBaseResponse.result = SResponseType.success
            }
            /** 返回结果对象 */
            sBaseResponse
        } catch (e: Exception) {
            e.printStackTrace()
            /** 返回结果，状态、以及报错信息 */
            SBaseResponse(SResponseType.failure,e.message!!)
        }
    } // Fun deletes()


} // Object RelationService