/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.meiku.controller

import com.persagy.base.extensions.toJson
import com.persagy.database.SFilter
import com.persagy.server.meiku.models.pic.Picture
import com.persagy.server.meiku.services.pic.PictureService
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import io.swagger.v3.oas.annotations.Operation
import io.swagger.v3.oas.annotations.tags.Tag
import lombok.extern.slf4j.Slf4j
import org.slf4j.LoggerFactory
import org.springframework.web.bind.annotation.*
import org.springframework.web.multipart.MultipartFile
import java.io.IOException
import java.util.*
import javax.servlet.ServletOutputStream
import javax.servlet.http.HttpServletResponse

/**
 * 图片接口
 *
 * @author wx
 */
@Tag(name = "006、图片接口")
@RestController
@RequestMapping("/picture")
@Slf4j
class PictureController {

    companion object {
        /** 日志 */
        private val logger = LoggerFactory.getLogger(PictureController::class.java)
    } // Companion object

    /**
     * 上传图片
     *
     * @param   file         图片文件
     * @param   uid          图片id
     * @return              创建结果信息
     */
   @Operation(summary = "上传图片", description = "")
    @PostMapping(value = ["/upload"])
    fun create(@RequestParam(value = "file", required = true) file: MultipartFile, @RequestParam(required = false) uid: String?): SCreateResponse<String> {
        var response = SCreateResponse<String>()
        try {
            val picture = Picture()
            if(uid.isNullOrEmpty()){
                picture.id = UUID.randomUUID().toString().replace("-","")
            }else{
                PictureService.delete(SFilter.eq("id",uid!!))
                picture.id = uid
            }
            picture.pic = file.bytes.toString()
            logger.debug("name："+file.name)
            logger.debug("长度："+file.size)
//            PictureService.insert(picture)
            response.result = SResponseType.success
            response.entityList = arrayListOf(picture.id!!)
        } catch (e: Exception) {
            response.result = SResponseType.failure
            response.message = e.message.toString()
            e.printStackTrace()
        }
        return response
    } // Function create()

    /**
     * 根据id删除图片
     *
     * @param   idList      id数组
     * @return              删除的结果信息
     */
   @Operation(summary = "根据id删除图片信息", description = "")
    @PostMapping(value = ["/delete"])
    fun delete(@RequestBody idList: ArrayList<Picture>): SBaseResponse {
        return PictureService.deleteByKeysList(idList)
    } // Function delete()

    /**
     * 查询图片信息
     *
     * @param   id             查询条件id
     * @return                 查询结果
     */
   @Operation(summary = "查询图片信息", description = "")
    @GetMapping(value = ["/query"])
    fun query(@RequestParam id: String,response: HttpServletResponse) {
        val picture = PictureService.select(SFilter.eq("id", id)).entity()
        if(picture!=null){
            response.contentType = "image/svg+xml;charset=UTF-8"

            // 将图像输出到Servlet输出流中
            val sos: ServletOutputStream
            try {
                sos = response.outputStream
                sos.write(picture.pic!!.toByteArray())
                sos.close()
            } catch (e: IOException) {
                e.printStackTrace()
            }
        }else{
            throw RuntimeException("图片不存在")
        }
            logger.debug(picture?.toJson())

    } // Function query()


} //