/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2009-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */

package com.persagy.server.meiku.services

import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.meiku.models.entities.MeiKu
import com.persagy.server.meiku.models.response.SCommonResponse
import com.persagy.service.SObjectService
import com.persagy.service.models.enums.SResponseType
import com.persagy.service.models.responses.SBaseResponse
import com.persagy.service.models.responses.SCreateResponse
import java.util.*

/**
 *
 * @author  wx
 * @date  2020/9/21 11:21
 */
object MeiKuService : SObjectService<MeiKu>(SMybatisDao(MeiKu::class.java)) {

    override fun onCreateBefore(entity: MeiKu): Boolean {
        if (entity.id.isNullOrEmpty()) {
            entity.id = UUID.randomUUID().toString().replace("-", "")
        }
        return super.onCreateBefore(entity)
    }

    /**
     * 保存
     */
    fun save(meiKu: MeiKu): SCreateResponse<MeiKu> {
        val sCreateResponse = SCreateResponse<MeiKu>()
        return try {
            if (meiKu.id.isNullOrEmpty()) {
                meiKu.id = UUID.randomUUID().toString().replace("-", "")
            }
            val insert = insert(meiKu)
            if (!meiKu.anchorList.isNullOrEmpty()) {
                for (anchor in meiKu.anchorList!!) {
                    anchor.meiKuId = meiKu.id
                    if (anchor.id.isNullOrEmpty()) {
                        anchor.id = UUID.randomUUID().toString().replace("-", "")
                    }
                    val insert1 = MeiKuAnchorService.insert(anchor)
                }
            }
            if (!meiKu.state .isNullOrEmpty()) {
                val stateList = meiKu.state
                for (state in stateList!!){
                    state!!.meiKuId = meiKu.id
                    if (state!!.id.isNullOrEmpty()) {
                        state!!.id = UUID.randomUUID().toString().replace("-", "")
                    }
                    MeiKuStateService.insert(state)
                }

            }
            sCreateResponse.entityList = arrayListOf(meiKu)
            sCreateResponse.result = SResponseType.success
            sCreateResponse
        } catch (e: Exception) {
            e.printStackTrace()
            sCreateResponse.result = SResponseType.failure
            sCreateResponse
        }
    } // Fun save()

    /**
     * 单个对象修改，包括下面节点
     */
    fun revise(meiKu: MeiKu): SBaseResponse {
        val sBaseResponse = SBaseResponse()
        return try {
            if (!meiKu.id.isNullOrEmpty()) {
                delete(SFilter.eq("id", meiKu.id!!))
                MeiKuAnchorService.delete(SFilter.eq("id", meiKu.id!!))
                MeiKuStateService.delete(SFilter.eq("id", meiKu.id!!))
                val insert = insert(meiKu)
                if (!meiKu.anchorList.isNullOrEmpty()){
                    for (anchor in meiKu.anchorList!!) {
                        anchor.meiKuId = meiKu.id
                        if (anchor.id.isNullOrEmpty()) {
                            anchor.id = UUID.randomUUID().toString().replace("-", "")
                        }
                        val insert1 = MeiKuAnchorService.insert(anchor)
                    }
                }
                if (!meiKu.state.isNullOrEmpty()) {
                    val stateList = meiKu.state
                    for (state in stateList!!){
                        state!!.meiKuId = meiKu.id
                        if (state!!.id.isNullOrEmpty()) {
                            state!!.id = UUID.randomUUID().toString().replace("-", "")
                        }
                        val insert1 = MeiKuStateService.insert(state)
                    }

                }
                sBaseResponse.result = SResponseType.success
            } else {
                sBaseResponse.result = SResponseType.failure
            }
            sBaseResponse
        } catch (e: Exception) {
            e.printStackTrace()
            sBaseResponse.result = SResponseType.failure
            sBaseResponse.message = e.message.toString()
            sBaseResponse
        }
    } // Fun revise()

    /**
     * 清除节点
     */
    override fun onDeleteSuccess(entityList: ArrayList<MeiKu>) {
        for (entity in entityList){
            MeiKuAnchorService.delete(SFilter.eq("id", entity.id!!))
            MeiKuStateService.delete(SFilter.eq("id", entity.id!!))
        }
        super.onDeleteSuccess(entityList)
    }

    /**
     * 读取图下面所有节点
     */
    fun read(meiKu: MeiKu):SCommonResponse<MeiKu>{
        val sQueryResponse = SCommonResponse<MeiKu>()
        return try {
            if (!meiKu.id.isNullOrEmpty()){
                val entity = select(SFilter.eq("id", meiKu.id!!)).entity()
                if (entity!=null){
                    val meiKuAnchorList = MeiKuAnchorService.select(SFilter.eq("id", meiKu.id!!)).exec()
                    if (meiKuAnchorList.size>0){
                        entity.anchorList = meiKuAnchorList
                    }
                    val meiKuState = MeiKuStateService.select(SFilter.eq("id", meiKu.id!!)).exec()
                    if (meiKuState!=null){
                        entity.state = meiKuState
                    }
                    sQueryResponse.content = entity
                    sQueryResponse.result = SResponseType.success
                }else{
                    sQueryResponse.result = SResponseType.failure
                }
            }else{
                sQueryResponse.result = SResponseType.failure
            }
             sQueryResponse
        } catch (e: Exception) {
            e.printStackTrace()
            sQueryResponse.result = SResponseType.failure
            sQueryResponse.message = e.message.toString()
            sQueryResponse
        }
    } // read()


} // Object MeiKuService